﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace howto_jpeg_to_jpg
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ofdFiles.Multiselect = true;
            clbFiles.CheckOnClick = true;
        }

        // Let the user select some files.
        private void mnuFileOpen_Click(object sender, EventArgs e)
        {
            if (ofdFiles.ShowDialog() == DialogResult.OK)
            {
                // Add the selected files to the lists.
                clbFiles.Items.Clear();
                foreach (string filename in ofdFiles.FileNames)
                {
                    FileNameInfo name_info = new FileNameInfo(filename);
                    int index = clbFiles.Items.Add(name_info);
                }

                // Check all of the files.
                clbFiles.CheckAll();
            }
        }

        // Rename the files.
        private void btnRename_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;

            int num_renamed = 0;
            foreach (FileNameInfo name_info in clbFiles.CheckedItems)
            {
                if (!RenameFile(name_info, ref num_renamed)) break;
            }

            // Remove the checked files from the list.
            clbFiles.RemoveChecked();

            Cursor = Cursors.Default;
            MessageBox.Show(string.Format("Renamed {0} files.", num_renamed)); 
        }

        // Rename the file. Return true if we should continue.
        private bool RenameFile(FileNameInfo name_info, ref int num_renamed)
        {
            // Ignore files that do not end with .jpeg.
            string old_name = name_info.FullName;
            if (!old_name.ToLower().EndsWith(".jpeg"))
                return true;

            // Compose the new file name.
            string new_name =
                old_name.Substring(0, old_name.Length - 4)
                + "jpg";

            // Try to rename the file.
            try
            {
                File.Move(old_name, new_name);
                num_renamed++;
                return true;
            }
            catch (IOException ex)
            {
                return MessageBox.Show("Cannot rename file "
                    + name_info.Name + ".\n\n" + ex.Message
                    + "\nDo you want to continue?",
                    "Rename Error",
                    MessageBoxButtons.YesNo) == DialogResult.Yes;
            }
        }
    }
}
